# FAQs
### On this page
  * [What Is a Fact Sheet?](https://help.sap.com/docs/leanix/ea/faqs#what-is-a-fact-sheet?)
  * [What Is a Workspace?](https://help.sap.com/docs/leanix/ea/faqs#what-is-a-workspace?)
  * [Which Browsers Are Supported?](https://help.sap.com/docs/leanix/ea/faqs#which-browsers-are-supported?)
  * [How Can I See the Current Version?](https://help.sap.com/docs/leanix/ea/faqs#how-can-i-see-the-current-version?)
  * [What Personal Data Is Stored in SAP LeanIX?](https://help.sap.com/docs/leanix/ea/faqs#what-personal-data-is-stored-in-sap-leanix?)
  * [How Can I Retrieve the Changelog for Any Changes Made to a User Within SAP LeanIX?](https://help.sap.com/docs/leanix/ea/faqs#how-can-i-retrieve-the-changelog-for-any-changes-made-to-a-user-within-sap-leanix?)
  * [Where Can I View and Access My Personal Data?](https://help.sap.com/docs/leanix/ea/faqs#where-can-i-view-and-access-my-personal-data?)
  * [How Can I Export My Data from SAP LeanIX?](https://help.sap.com/docs/leanix/ea/faqs#how-can-i-export-my-data-from-sap-leanix?)
  * [Implemented Security Measures in SAP LeanIX](https://help.sap.com/docs/leanix/ea/faqs#implemented-security-measures-in-sap-leanix)


Find answers to frequently asked questions about SAP LeanIX.
